From 55593a7c1abad84833ae81a965d131c8fd99619f Mon Sep 17 00:00:00 2001
From: Tim Zimmermann <tim@linux4.de>
Date: Wed, 17 Aug 2022 18:08:25 +0200
Subject: [PATCH 01/12] exynos9820-common: Use libutils from VNDK32 for HWC and
 sensors

* For sensors.sensorhub.so and libexynosdisplay.so
* Abort message: 'incStrongRequireStrong() called on 0x7586a3a1c0 which isn't already owned'
* Unfortunately the HIDL service loads libutils.so too, so that needs to be patched instead

Change-Id: Ibca93bc356b81e205c77df5992b2ae1ded9bb83b
---
 Android.mk            | 16 +++++++++++++---
 proprietary-files.txt |  4 ++++
 2 files changed, 17 insertions(+), 3 deletions(-)

diff --git a/Android.mk b/Android.mk
index ca7afd0e0..d6cc5922e 100644
--- a/Android.mk
+++ b/Android.mk
@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2021 The LineageOS Project
+# Copyright (C) 2021-2022 The LineageOS Project
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,12 +33,22 @@ $(EGL_32_SYMLINKS): $(LOCAL_INSTALLED_MODULE)
 	$(hide) ln -sf /vendor/lib/egl/libGLES_mali.so $@
 
 EGL_64_SYMLINKS := $(addprefix $(TARGET_OUT_VENDOR)/lib64/,$(EGL_LIBS))
-$(EGL_64_SYMLINKS): $(LOCAL_INSTALLED_MODULE)
+$(EGL_64_SYMLINKS): $(LOCAL_INSTALLED_MODULE) $(LIBUTILS32_FILES)
 	@echo "EGL 64 lib link: $@"
 	@mkdir -p $(dir $@)
 	@rm -rf $@
 	$(hide) ln -sf /vendor/lib64/egl/libGLES_mali.so $@
 
-ALL_DEFAULT_INSTALLED_MODULES += $(EGL_32_SYMLINKS) $(EGL_64_SYMLINKS)
+LIBUTILS32_SERVICES := \
+    android.hardware.graphics.composer@2.2-service \
+    android.hardware.sensors@2.1-service.samsung-multihal
+LIBUTILS32_FILES := $(addprefix $(TARGET_OUT_VENDOR)/bin/hw/,$(LIBUTILS32_SERVICES))
+LIBUTILS32_SYMLINK := $(TARGET_OUT_VENDOR)/lib64/libuti32.so
+$(LIBUTILS32_SYMLINK): $(LOCAL_INSTALLED_MODULE) $(LIBUTILS32_FILES)
+	@mkdir -p $(dir $@)
+	@rm -rf $@
+	$(hide) ln -sf /vendor/lib64/libutils-v32.so $@
+	$(hide) sed -i 's/libutils\.so/libuti32.so/g' $(LIBUTILS32_FILES)
 
+ALL_DEFAULT_INSTALLED_MODULES += $(EGL_32_SYMLINKS) $(EGL_64_SYMLINKS) $(LIBUTILS32_SYMLINK)
 endif
diff --git a/proprietary-files.txt b/proprietary-files.txt
index da9472407..6ff914c43 100644
--- a/proprietary-files.txt
+++ b/proprietary-files.txt
@@ -238,3 +238,7 @@ vendor/firmware/bcmdhd_sta.bin_b1
 vendor/firmware/nvram.txt_ES00_semco_b0
 vendor/firmware/nvram.txt_ES01_semco_b0
 vendor/firmware/nvram.txt_ES02_semco_b0
+
+## VNDK
+# libutils - from prebuilts/vndk/v32 - android-13.0.0_r3
+-vendor/lib64/libuti32.so|79e694bea942225a64e768468000dce3a0e44b22
-- 
2.35.1

